@@ -1,4 +1,5 @@
 #include "log.h"
+
 #include <sys/file.h>
 
 #define LOG_BUF_SIZE 1024 * 16
@@ -6,111 +7,99 @@
 static PyObject *access_logger;
 static PyObject *err_logger;
 
-int
-set_access_logger(PyObject *obj)
-{
-    if(access_logger != NULL){
-        Py_DECREF(access_logger);
-    }
-    access_logger = obj;
-    //Py_INCREF(access_logger);
-    return 1;
+int set_access_logger(PyObject *obj) {
+  if (access_logger != NULL) {
+    Py_DECREF(access_logger);
+  }
+  access_logger = obj;
+  // Py_INCREF(access_logger);
+  return 1;
 }
 
-int
-set_err_logger(PyObject *obj)
-{
-    if(err_logger != NULL){
-        Py_DECREF(err_logger);
-    }
-    err_logger = obj;
-    //Py_INCREF(err_logger);
-    return 1;
+int set_err_logger(PyObject *obj) {
+  if (err_logger != NULL) {
+    Py_DECREF(err_logger);
+  }
+  err_logger = obj;
+  // Py_INCREF(err_logger);
+  return 1;
 }
 
-int
-call_access_logger(PyObject *environ)
-{
-    PyObject *args = NULL, *res = NULL;
+int call_access_logger(PyObject *environ) {
+  PyObject *args = NULL, *res = NULL;
 
-    if(access_logger){
-        if(environ == NULL){
-            environ = Py_None;
-            Py_INCREF(environ);
-        }
-
-        DEBUG("call access logger %p", access_logger);
-        args = PyTuple_Pack(1, environ);
-        res = PyObject_CallObject(access_logger, args);
-        Py_DECREF(args);
-        Py_XDECREF(res);
-        if(PyErr_Occurred()){
-            PyErr_Print();
-            PyErr_Clear();
-        }
+  if (access_logger) {
+    if (environ == NULL) {
+      environ = Py_None;
+      Py_INCREF(environ);
     }
-    return 1;
+
+    DEBUG("call access logger %p", access_logger);
+    args = PyTuple_Pack(1, environ);
+    res = PyObject_CallObject(access_logger, args);
+    Py_DECREF(args);
+    Py_XDECREF(res);
+    if (PyErr_Occurred()) {
+      PyErr_Print();
+      PyErr_Clear();
+    }
+  }
+  return 1;
 }
 
+int call_error_logger(void) {
+  PyObject *exception = NULL, *v = NULL, *tb = NULL;
+  PyObject *args = NULL, *res = NULL;
 
-int
-call_error_logger(void)
-{
-    PyObject *exception = NULL, *v = NULL, *tb = NULL;
-    PyObject *args = NULL, *res = NULL;
+  if (err_logger) {
+    PyErr_Fetch(&exception, &v, &tb);
+    if (exception == NULL) {
+      goto err;
+    }
+    PyErr_NormalizeException(&exception, &v, &tb);
+    if (exception == NULL) {
+      goto err;
+    }
+    DEBUG("exc:%p val:%p tb:%p", exception, v, tb);
+    /* PySys_SetObject("last_type", exception); */
+    /* PySys_SetObject("last_value", v); */
+    /* PySys_SetObject("last_traceback", tb); */
 
-    if(err_logger){
-        PyErr_Fetch(&exception, &v, &tb);
-        if(exception == NULL){
-            goto err;
-        }
-        PyErr_NormalizeException(&exception, &v, &tb);
-        if(exception == NULL){
-            goto err;
-        }
-        DEBUG("exc:%p val:%p tb:%p",exception, v, tb);
-        /* PySys_SetObject("last_type", exception); */
-        /* PySys_SetObject("last_value", v); */
-        /* PySys_SetObject("last_traceback", tb); */
-        
-        if(v == NULL){
-            v = Py_None;
-            Py_INCREF(v);
-        }
-        if(tb == NULL){
-            tb = Py_None;
-            Py_INCREF(tb);
-        }
-        PyErr_Clear();
-
-        args = PyTuple_Pack(3, exception, v, tb);
-        if(args == NULL){
-            PyErr_Print();
-            goto err;
-        }
-        DEBUG("call error logger %p", err_logger);
-        res = PyObject_CallObject(err_logger, args);
-        Py_DECREF(args);
-        Py_XDECREF(res);
-        Py_XDECREF(exception);
-        Py_XDECREF(v);
-        Py_XDECREF(tb);
-        if(res == NULL){
-            PyErr_Print();
-        }
-    }else{
-        PyErr_Print();
+    if (v == NULL) {
+      v = Py_None;
+      Py_INCREF(v);
+    }
+    if (tb == NULL) {
+      tb = Py_None;
+      Py_INCREF(tb);
     }
-err:
     PyErr_Clear();
-    return 1;
+
+    args = PyTuple_Pack(3, exception, v, tb);
+    if (args == NULL) {
+      PyErr_Print();
+      goto err;
+    }
+    DEBUG("call error logger %p", err_logger);
+    res = PyObject_CallObject(err_logger, args);
+    Py_DECREF(args);
+    Py_XDECREF(res);
+    Py_XDECREF(exception);
+    Py_XDECREF(v);
+    Py_XDECREF(tb);
+    if (res == NULL) {
+      PyErr_Print();
+    }
+  } else {
+    PyErr_Print();
+  }
+err:
+  PyErr_Clear();
+  return 1;
 }
 
-
-int
-open_log_file(const char *path)
-{
-    return open(path, O_CREAT|O_APPEND|O_WRONLY, 0744);
+int open_log_file(const char *path) {
+  return open(path, O_CREAT | O_APPEND | O_WRONLY, 0744);
 }
 
 /*
@@ -144,9 +133,8 @@ write_error_log(char *file_name, int line)
         return -1;
     }
 
-    snprintf(buf, 256, "pid %d, File \"%s\", line %d \n", getpid(), file_name, line);
-    ret = write(fd, buf, strlen(buf));
-    if(ret < 0){
+    snprintf(buf, 256, "pid %d, File \"%s\", line %d \n", getpid(), file_name,
+line); ret = write(fd, buf, strlen(buf)); if(ret < 0){
         PyErr_SetFromErrno(PyExc_IOError);
         return -1;
     }
@@ -177,7 +165,7 @@ write_log(const char *new_path, int fd, const char *data, size_t len)
         openfd = open_log_file(new_path);
         if(openfd < 0){
             //fail
-            return -1; 
+            return -1;
         }
 
         flock(openfd, LOCK_EX);
@@ -242,12 +230,8 @@ write_access_log(client_t *cli, int log_fd, const char *log_path)
         //update
         cache_time_update();
 
-        snprintf(buf, LOG_BUF_SIZE, "%s - - [%s] \"%s %s %s\" %d %d \"%s\" \"%s\"\n",
-               cli->remote_addr,
-               http_log_time,
-               method,
-               path,
-               version,
+        snprintf(buf, LOG_BUF_SIZE, "%s - - [%s] \"%s %s %s\" %d %d \"%s\"
+\"%s\"\n", cli->remote_addr, http_log_time, method, path, version,
                cli->status_code,
                cli->write_bytes,
                referer,
@@ -257,4 +241,3 @@ write_access_log(client_t *cli, int log_fd, const char *log_path)
     return 0;
 }
 */
-
