@@ -1,10 +1,10 @@
 /*
  * Copyright (c) 2009, Cybozu Labs, Inc.
  * All rights reserved.
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
- * 
+ *
  * * Redistributions of source code must retain the above copyright notice,
  *   this list of conditions and the following disclaimer.
  * * Redistributions in binary form must reproduce the above copyright notice,
@@ -13,7 +13,7 @@
  * * Neither the name of the <ORGANIZATION> nor the names of its contributors
  *   may be used to endorse or promote products derived from this software
  *   without specific prior written permission.
- * 
+ *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -31,10 +31,20 @@
 #include <errno.h>
 #include <sys/epoll.h>
 #include <unistd.h>
+
 #include "picoev.h"
+#include "time_cache.h"
 
 #ifndef PICOEV_EPOLL_DEFER_DELETES
-# define PICOEV_EPOLL_DEFER_DELETES 1
+#define PICOEV_EPOLL_DEFER_DELETES 1
+#endif
+
+// EPOLLEXCLUSIVE was added in Linux 4.5
+// When using backported (new) kernel, kernel supports it in spite of
+// sys/epoll.h doesn't define it.
+// Kernel older than 4.5 ignores this flag.  So we can pass it safely.
+#ifndef EPOLLEXCLUSIVE
+#define EPOLLEXCLUSIVE (1 << 28)
 #endif
 
 typedef struct picoev_loop_epoll_st {
@@ -45,10 +55,9 @@ typedef struct picoev_loop_epoll_st {
 
 picoev_globals picoev;
 
-picoev_loop* picoev_create_loop(int max_timeout)
-{
+picoev_loop* picoev_create_loop(int max_timeout) {
   picoev_loop_epoll* loop;
-  
+
   /* init parent */
   assert(PICOEV_IS_INITED);
   if ((loop = (picoev_loop_epoll*)malloc(sizeof(picoev_loop_epoll))) == NULL) {
@@ -58,22 +67,21 @@ picoev_loop* picoev_create_loop(int max_timeout)
     free(loop);
     return NULL;
   }
-  
+
   /* init myself */
   if ((loop->epfd = epoll_create(picoev.max_fd)) == -1) {
     picoev_deinit_loop_internal(&loop->loop);
     free(loop);
     return NULL;
   }
-  
-  loop->loop.now = time(NULL);
+
+  loop->loop.now = current_msec / 1000;
   return &loop->loop;
 }
 
-int picoev_destroy_loop(picoev_loop* _loop)
-{
+int picoev_destroy_loop(picoev_loop* _loop) {
   picoev_loop_epoll* loop = (picoev_loop_epoll*)_loop;
-  
+
   if (close(loop->epfd) != 0) {
     return -1;
   }
@@ -82,30 +90,30 @@ int picoev_destroy_loop(picoev_loop* _loop)
   return 0;
 }
 
-int picoev_update_events_internal(picoev_loop* _loop, int fd, int events)
-{
+int picoev_update_events_internal(picoev_loop* _loop, int fd, int events) {
   picoev_loop_epoll* loop = (picoev_loop_epoll*)_loop;
   picoev_fd* target = picoev.fds + fd;
   struct epoll_event ev;
   int epoll_ret;
-  
+
   assert(PICOEV_FD_BELONGS_TO_LOOP(&loop->loop, fd));
-  
+
   if (unlikely((events & PICOEV_READWRITE) == target->events)) {
     return 0;
   }
-  
-  ev.events = ((events & PICOEV_READ) != 0 ? EPOLLIN : 0)
-    | ((events & PICOEV_WRITE) != 0 ? EPOLLOUT : 0);
+
+  ev.events = ((events & PICOEV_READ) != 0 ? EPOLLIN : 0) |
+              ((events & PICOEV_WRITE) != 0 ? EPOLLOUT : 0);
   ev.data.fd = fd;
-  
-#define SET(op, check_error) do {		    \
+
+#define SET(op, check_error)                        \
+  do {                                              \
     epoll_ret = epoll_ctl(loop->epfd, op, fd, &ev); \
-    assert(! check_error || epoll_ret == 0);	    \
+    assert(!check_error || epoll_ret == 0);         \
   } while (0)
-  
+
 #if PICOEV_EPOLL_DEFER_DELETES
-  
+
   if ((events & PICOEV_DEL) != 0) {
     /* nothing to do */
   } else if ((events & PICOEV_READWRITE) == 0) {
@@ -114,37 +122,41 @@ int picoev_update_events_internal(picoev_loop* _loop, int fd, int events)
     SET(EPOLL_CTL_MOD, 0);
     if (epoll_ret != 0) {
       assert(errno == ENOENT);
+      ev.events |= EPOLLEXCLUSIVE;
       SET(EPOLL_CTL_ADD, 1);
     }
   }
-  
+
 #else
-  
+
   if ((events & PICOEV_READWRITE) == 0) {
     SET(EPOLL_CTL_DEL, 1);
   } else {
-    SET(target->events == 0 ? EPOLL_CTL_ADD : EPOLL_CTL_MOD, 1);
+    if (target->events == 0) {
+      ev.events |= EPOLLEXCLUSIVE;
+      SET(EPOLL_CTL_ADD, 1);
+    } else {
+      SET(EPOLL_CTL_MOD, 1);
+    }
   }
-  
+
 #endif
-  
+
 #undef SET
-  
+
   target->events = events;
-  
+
   return 0;
 }
 
-int picoev_poll_once_internal(picoev_loop* _loop, int max_wait)
-{
+int picoev_poll_once_internal(picoev_loop* _loop, int max_wait) {
   picoev_loop_epoll* loop = (picoev_loop_epoll*)_loop;
   int i, nevents;
-  
-  Py_BEGIN_ALLOW_THREADS
-  nevents = epoll_wait(loop->epfd, loop->events,
-		       sizeof(loop->events) / sizeof(loop->events[0]),
-		       max_wait * 1000);
-  Py_END_ALLOW_THREADS
+
+  Py_BEGIN_ALLOW_THREADS nevents = epoll_wait(
+      loop->epfd, loop->events, sizeof(loop->events) / sizeof(loop->events[0]),
+      max_wait * 1000);
+  Py_END_ALLOW_THREADS cache_time_update();
 
   if (nevents == -1) {
     return -1;
@@ -152,10 +164,13 @@ int picoev_poll_once_internal(picoev_loop* _loop, int max_wait)
   for (i = 0; likely(i < nevents); ++i) {
     struct epoll_event* event = loop->events + i;
     picoev_fd* target = picoev.fds + event->data.fd;
-    if (loop->loop.loop_id == target->loop_id && likely((target->events & PICOEV_READWRITE) != 0)) {
-      int revents = ((event->events & EPOLLIN) != 0 ? PICOEV_READ : 0) | ((event->events & EPOLLOUT) != 0 ? PICOEV_WRITE : 0);
+    if (loop->loop.loop_id == target->loop_id &&
+        likely((target->events & PICOEV_READWRITE) != 0)) {
+      int revents = ((event->events & EPOLLIN) != 0 ? PICOEV_READ : 0) |
+                    ((event->events & EPOLLOUT) != 0 ? PICOEV_WRITE : 0);
       if (likely(revents != 0)) {
-        (*target->callback)(&loop->loop, event->data.fd, revents, target->cb_arg);
+        (*target->callback)(&loop->loop, event->data.fd, revents,
+                            target->cb_arg);
       }
     } else {
 #if PICOEV_EPOLL_DEFER_DELETES
